@@ -1,6 +1,7 @@
 from collections import defaultdict
 from itertools import product
 from json import dump
+from json import load
 from typing import Any
 from typing import Dict
 from typing import Iterable
@@ -107,6 +108,7 @@ class QuickTradeTuner(object):
                 self.result_tunes[ticker][interval][limit][strat_kw]['losses'] = trader.losses
                 self.result_tunes[ticker][interval][limit][strat_kw]['profits'] = trader.profits
                 self.result_tunes[ticker][interval][limit][strat_kw]['percentage year profit'] = trader.year_profit
+                self.result_tunes[ticker][interval][limit][strat_kw]['mean deviation'] = trader.mean_deviation
                 if self.multi_test:
                     ticker = old_tick
                 if use_tqdm:
@@ -151,6 +153,11 @@ class QuickTradeTuner(object):
         with open(path, 'w') as file:
             dump(self.result_tunes, file)
 
+    def load_tunes(self, path: str = 'returns.json'):
+        utils.logger.debug('loading tunes from %s', path)
+        with open(path, 'r') as file:
+            self.result_tunes = load(file)
+
 
 class Choise(TunableValue):
     pass
